@@ -76,7 +76,13 @@ prepare_data <- function(y, X, type = "linear", candidates = NULL, Xadd = NULL,
 
   # type
   stopifnot(type %in% c("linear", "logistic", "poisson"))
-  fit_fun <- fit_linear
+  if (type == "logistic") {
+    fit_fun <- fit_logistic
+  } else if (type == "poisson") {
+    fit_fun <- fit_poisson
+  } else {
+    fit_fun <- fit_linear
+  }
 
   # candidates
   if (is.null(candidates)) candidates <- 1:p
@@ -103,7 +109,7 @@ prepare_data <- function(y, X, type = "linear", candidates = NULL, Xadd = NULL,
 
   # others
   crit <- NULL
-  metric <- "MSE"
+  metric <- ifelse(type == "logistic", "ACC", "MSE")
   metric_v <- NULL
   stepwise <- FALSE
   stay <- 1:ncol(Xm)
